Compute Loewe combination index isobolograms for a combination SE,
writing results to the isobolograms and all_iso_points assays.
This is step 4 of the fit_SE.combinations pipeline.
Usage
apply_combo_isobolograms(
se,
series_identifiers = NULL,
normalization_types = c("GR", "RV"),
averaged_assay = "Averaged",
metrics_assay = "Metrics",
isobolograms_assay = "isobolograms",
iso_points_assay = "all_iso_points"
)Arguments
- se
SummarizedExperimentwithAveragedandMetricsassays.- series_identifiers
character vector of length 2. Defaults to
get_default_nested_identifiers(se, ...).- normalization_types
character vector. Default
c("GR", "RV").- averaged_assay
string. Default
"Averaged".- metrics_assay
string. Default
"Metrics".- isobolograms_assay
string; name of the Loewe curves output assay. Default
"isobolograms".- iso_points_assay
string; name of the iso points output assay. Default
"all_iso_points".
Details
Requires the Averaged and Metrics assays (as produced by
apply_combo_sa_fits or fit_SE.combinations).
Isobologram analysis is only performed when at least 9 combo concentration
points are available — otherwise NA is written, matching
fit_SE.combinations behaviour.
Examples
mae <- gDRutils::get_synthetic_data("finalMAE_combo_matrix_small")
combo_se <- mae[[gDRutils::get_supported_experiments("combo")]]
combo_se_iso <- apply_combo_isobolograms(combo_se[1, 1])
"isobolograms" %in% SummarizedExperiment::assayNames(combo_se_iso)
#> [1] TRUE